玛丽和马克思 (豆瓣)
Description: 玛丽和马克思电影简介和剧情介绍,玛丽和马克思影评、图片、预告片、影讯、论坛、在线购票
Keywords: 玛丽和马克思,Mary and Max,玛丽和马克思影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.136豆瓣电影Top250

# 玛丽和马克思 Mary and Max (2009)

导演: 亚当·艾略特
编剧: 亚当·艾略特
主演: 托妮·科莱特 / 菲利普·塞默·霍夫曼 / 巴瑞·哈姆弗莱斯 / 艾瑞克·巴纳 / 贝塔尼·维特莫尔 / 蕾妮·盖耶 / 伊恩·莫利·梅尔德伦 / 朱莉·福塞斯 / 约翰·弗劳思 / 克里斯托弗·马西 / 卡罗琳·莎士比亚-艾伦 / 琳恩·史密斯 / 迈克尔·延纳
类型: 剧情 / 喜剧 / 动画
制片国家/地区: 澳大利亚 / 美国
语言: 英语 / 意第绪语
上映日期: 2009-01-15(圣丹斯电影节) / 2009-04-09(澳大利亚)
片长: 92分钟
又名: 巧克力情缘(台) / 同是天涯寂寞客 / 玛丽和麦克斯 / 玛丽与马克思 / 玛丽和马克斯 / 玛丽和马科斯
IMDb: tt0978762
豆瓣评分
引用
8.9
408065人评价
5星
57.6%
4星
33.4%
3星
8.0%
2星
0.7%
1星
0.2%
好于 97% 动画片
好于 98% 剧情片
想看 看过
评价:
推荐

## 玛丽和马克思的剧情简介 · · · · · ·

1976年，8岁的玛丽·黛西·丁格尔（贝丝妮·惠特摩尔 Bethany Whitmore 配音）是澳大利亚墨尔本的一个小女孩，喜欢动画片“诺布利特”、甜炼乳和巧克力。玛丽的妈妈是个酒鬼，而在茶叶包装厂工作的父亲平日只喜欢制作鸟标本。孤独的玛丽没有朋友，某一天心血来潮给美国纽约市的马克思·杰瑞·霍罗威茨（菲利普·塞默·霍夫曼 Philip Seymour Hoffman 配音）写了一封信询问美国小孩从哪里来，并附上一根樱桃巧克力棒。44岁的马克思患有自闭症及肥胖，碰巧也喜欢看“诺布利特”动画片及吃巧克力。二人的笔友关系从1976年维持到1994年，期间各自经历了许多人生起伏，直到成年的玛丽（托妮·科莱特 Toni Collette 配音）终于来到纽约看望马克思……
本片获2009年法国昂锡国际动画影展最佳动画长片奖，柏林国际电影节水晶熊奖及渥太华国际动... (展开全部) 1976年，8岁的玛丽·黛西·丁格尔（贝丝妮·惠特摩尔 Bethany Whitmore 配音）是澳大利亚墨尔本的一个小女孩，喜欢动画片“诺布利特”、甜炼乳和巧克力。玛丽的妈妈是个酒鬼，而在茶叶包装厂工作的父亲平日只喜欢制作鸟标本。孤独的玛丽没有朋友，某一天心血来潮给美国纽约市的马克思·杰瑞·霍罗威茨（菲利普·塞默·霍夫曼 Philip Seymour Hoffman 配音）写了一封信询问美国小孩从哪里来，并附上一根樱桃巧克力棒。44岁的马克思患有自闭症及肥胖，碰巧也喜欢看“诺布利特”动画片及吃巧克力。二人的笔友关系从1976年维持到1994年，期间各自经历了许多人生起伏，直到成年的玛丽（托妮·科莱特 Toni Collette 配音）终于来到纽约看望马克思……
本片获2009年法国昂锡国际动画影展最佳动画长片奖，柏林国际电影节水晶熊奖及渥太华国际动画电影节最高奖。 ©豆瓣

## 玛丽和马克思的演职员 · · · · · · ( 全部 15 )

- 亚当·艾略特 导演
- 托妮·科莱特 配 玛丽·黛西·丁格尔 Mary Daisy Dinkle
- 菲利普·塞默·霍夫曼 配 马克思·杰瑞·霍罗威茨 Max Jerry Horovitz
- 巴瑞·哈姆弗莱斯 配 旁白 Narrator
- 艾瑞克·巴纳 配 达米安 Damien
- 贝塔尼·维特莫尔 配 小玛丽 Young Mary Daisy Dinkle

## 玛丽和马克思的视频和图片 · · · · · · ( 预告片1 | 添加视频评论 | 图片620 · 添加 )

## 喜欢这部电影的人也喜欢 · · · · · ·

  天空之城

  幽灵公主

  大闹天宫

  风之谷

  哈尔的移动城堡

  魔女宅急便

  玩具总动员

  疯狂约会美丽都

  怪兽电力公司

  红辣椒

我要写短评

## 玛丽和马克思的短评 · · · · · · ( 全部 113046 条 )

热门 / 最新 / 好友

### 3970 有用 阿北 看过 2009-12-02 23:02:50

伤心电影，好电影。结尾告诉我们，网友见面要早。

### 3036 有用 二甲 看过 2009-10-27 20:30:08

个人认为影片比《飞屋环游记》要出色

### 2909 有用 Doublebitch 看过 2009-11-02 19:14:18

年轻时我想变成任何人除了自己。

### 2221 有用 mayfly 看过 2009-11-16 18:54:13

PS,娘的，我看哭了。PPS,推荐给所有的人看。PPPS,可以打十星吗？

### 1587 有用 披着人皮的鬼 看过 2009-11-12 23:33:46

拍电影是不是和做爱一样 只有技术做不出感情

> 更多短评 113046条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 玛丽和马克思的影评 · · · · · · ( 全部 2975 条 )

热门 / 最新 / 好友
小斑 2009-10-10 03:39:40

## 我們宅的不是寂寞，是境界

这篇影评可能有剧透

電影結束的時候，坐在我旁邊的法國美眉哭了，而我這個看電影哭點很低的人連鼻子都沒有酸一下。不難過，平靜死去的Max表情安詳，他胸前掛著那本用來辨識人的表情的小冊子，是為了準備見他人生中唯一的朋友。他等的人來了，為他流下了眼淚，這一切不是很好嗎？如果Max見到了Mary... (展开)
4870 248 487回应 收起
Doublebitch 2009-11-02 21:25:54

## 我想变成任何一个人除了自己

《玛丽和马克思》可能是我今年看过制作最朴实的动画电影，泥土捏制的人物造型和逐帧拍摄的手法在推崇“科技”和“仿真”的现在电影中已经十分少见。但这部没有炫目的视觉特效、没有英雄主义渲染、也没有大规模的宣传造势的偏独立电影所带给人心灵上的震撼却多过任何一部3D大片... (展开)
3883 105 341回应 收起
李伯伯 2009-11-03 17:32:28

## 孤独的人是可耻的

Max在影片最后的那封信中说： The reason i forgive you is because you are not perfect. You are imperfect,and so am i. All humans are imperfect,even the man outside my apartment who litters. When i was young,i wanted to be anybody but myself. Dr Bernard Hazelh... (展开)
2483 134 233回应 收起
隆咚锵 2009-11-28 09:30:56

## I was Max once

因为不想成为可耻的人，所以在人生的道路上才不断地在寻找朋友。我就是这样，常常为这个过程感到无限的疲惫。其实，往往是那些安静的孤独的晚上，对着键盘的时刻，才让我感到无比的自在。如果说我是Max的话，我宁愿就这样在某个清晨悄悄的死去而不打扰到曾经让我学会微笑的朋友... (展开)
1318 22 195回应 收起
男娼起义 2009-12-31 18:14:17

## 我们生来就是孤独

今年最后一篇评论，给我今年最爱的《玛丽和马克思》。 一 我觉得每个人的各个人生阶段都会有一部标签式的电影，也许很多年之后翻过来看的时候是可笑而滑稽的，但那的确是当时的的状态，等哪天想回忆什么的时候，就找出来看看，让电影里的演员上演自己的回忆。人生就好像一... (展开)
871 46 156回应 收起
桑克 2009-11-14 09:39:50

## 细腻而笨拙的封闭与悲伤

这篇影评可能有剧透

一个44岁的男人，肥胖，喜欢吃巧克力热狗，喜欢看动画片《诺布莱一家》，做过六份工作，多数乏善可陈，唯一有趣的是在做清洁工的时候扮过机器人，机械而幽默地倒垃圾，结果却被一位不欣赏的阿姨报了警。他是一个犹太人，读了不少书之后，却不信上帝了，但他仍旧戴着犹太小... (展开)
466 8 40回应 收起
blueshadow 2009-10-24 22:36:59

## 世界上每个角落里的人（与本片无关）

没有人是完美的，可是几乎所有人都在花费大量时间努力成为somebody else。 一个别的什么人。一个标准的人。 因此你得学会憎恨自己，焦虑感冉冉而生，每日三省吾身，免得成为坏孩子或变态 因为我们心中的somebody else——那几乎是唯一的正确的选择，光明的大道，照亮航程的灯塔... (展开)
400 18 85回应 收起
艾小柯 2010-02-15 11:11:41

## 最幸运的事

“灵魂伴侣”（soulmate）是个技术含量极高的词。它比友谊更深入，比爱情更严肃，比亲情更纯粹。它可能是柏拉图式的高端精神恋爱，也可以是人生路上默默无言的相伴相扶，甚至还可能是两个从未见过面的人之间的鸿雁传书，比如粘土动画片《玛丽与马克思》。 电影的画面特质和它... (展开)
309 12 50回应 收起
宋绪新 2009-12-09 13:38:45

## 《玛丽和马克思》：假如玛丽给我写了那封信

Mary（来信） 亲爱的宋绪新先生： 我叫做Mary Daisy Dinkle。 我现在八岁三个月零九天大了。 我最喜欢的颜色是棕色，我最喜欢吃甜炼乳，第二喜欢吃的是巧克力。 我有一只叫做Ehtel的鸡……这是他的画像。他从来不下蛋不过有一天他会下的。 我妈妈喜欢抽烟、板球和雪利酒。 我... (展开)
278 9 116回应 收起
tonijin 2009-10-27 09:02:32

## 你的人生有裂缝吗

“每个人的人生就是一条很长的人行道，有的很整洁，而有的象我一样，有裂缝香蕉皮和烟头，你的人行道象我一样，但是没有我的这么多裂缝。。” 玛丽和马克思，两个本质孤独，困惑的人，在这个荒诞冰冷的世界里寻找人性最根本的一点温暖，那是人与人之间最本真，最质朴的交流，在... (展开)
169 17 33回应 收起

> 更多影评 2975篇

添加新讨论

## 讨论区 · · · · · ·

求问为什么马克思生气了 | 来自自闭症儿童 | 14 回应 | 2022-11-21 19:04:16
因为非常非常喜欢，我制作了他们，我还会继续做，... | 来自橙鲤 | 17 回应 | 2022-11-20 17:01:19
有没有95后并不会感受到这部影片所带来的感动和震... | 来自乖张 Paul | 226 回应 | 2022-11-12 10:11:41
请问适合八岁孩子看吗？谢谢 | 来自yanying | 3 回应 | 2022-11-12 10:04:08
玛丽和马克思 | 来自时倾. |  | 2022-11-02 11:52:51

> 去这部影片的讨论区（全部350条）

## 关于《玛丽和马克思》的问题 · · · · · · ( 全部29个 )

- 玛丽试图自杀时的歌曲是不是在后会无期里有？ 8人回答
- 玛丽写了本研究精神病的书,马克思为什么生气? 21人回答

> 全部29个问题

## 在哪儿看这部电影 · · · · · ·

- 咪咕视频 免费观看
- 腾讯视频 免费观看
- 西瓜视频 免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- 【内牛满面】 (影志)
- 【豆瓣高分动画长片】 (影志)
- 那些牛叉闪闪的片子 (家庭种菜笔记)
- 简直想打十星 (chrissy)
- 治愈系动画推荐 ([己注销])

## 谁在看这部电影 · · · · · ·

- 落落的暮暮
  1分钟前 想看
- 豆友O4WfE_FJiI
  8分钟前 看过
- 要成为开心怪👻
  13分钟前 想看

556477人看过 / 267715人想看

订阅玛丽和马克思的评论:
feed: rss 2.0